@@ -1,7 +1,7 @@
 release_questions <- function() {
   c(
     "Is the code free of #TODOs?",
-    "Have you updated references to Smith (2020; 2021) in Readme, R/Quartet-Package, & inst/REFS?",
+    "Have you updated references to Smith (2022) in Readme, R/Quartet-Package, & inst/REFS?",
     "Have you updated the version number in .zenodo.json?",
     "Have you checked the Vignettes for sanity?"
   )
