@@ -1,10 +1,7 @@
-context("Plotting functions")
-
-data('sq_trees')
+data("sq_trees")
 
 test_that("Splits comparisons are correct", {
   
-  
   expect_equal(c(length(sq_trees), 3), dim(BipartitionPoints(sq_trees)))
   expect_identical(8, unique(rowSums(BipartitionPoints(sq_trees))))
   expect_equal(c(length(sq_trees), 3), dim(BipartitionPoints(sq_trees, cf=sq_trees$collapse_some)))
